==> nomachine-8.8.1-1-x86_64.pkg.tar.zst: NX/lib/perl/nxnode/Common/NXShellCommands.pm <==
############################################################################
#                                                                          #
#  Copyright (c) 2001, 2023 NoMachine, http://www.nomachine.com.           #
#                                                                          #
#  NXNODE, NX protocol compression and NX extensions to this software      #
#  are copyright of NoMachine. Redistribution and use of the present       #
#  software is allowed according to terms specified in the file LICENSE    #
#  which comes in the source distribution.                                 #
#                                                                          #
#  Check http://www.nomachine.com/licensing.html for applicability.        #
#                                                                          #
#  NX and NoMachine are trademarks of NoMachine S.a.r.l.                   #
#                                                                          #
#  All rights reserved.                                                    #
#                                                                          #
############################################################################
package Common::NXShellCommands;no warnings;($pathNotFound=
"\x5f\x5f\x4e\x4f\x4e\x45\x5f\x5f");($commandSs="\x5f\x5f\x53\x53\x5f\x5f");(
$commandNetstat="\x5f\x5f\x4e\x45\x54\x53\x54\x41\x54\x5f\x5f");sub checkPath{(my $command
=shift (@_));if (-x (("\x2f\x62\x69\x6e\x2f".$command))){return ((
"\x2f\x62\x69\x6e\x2f".$command));}elsif (-x (("\x2f\x73\x62\x69\x6e\x2f".
$command))){return (("\x2f\x73\x62\x69\x6e\x2f".$command));}elsif (-x ((
"\x2f\x75\x73\x72\x2f\x62\x69\x6e\x2f".$command))){return ((
"\x2f\x75\x73\x72\x2f\x62\x69\x6e\x2f".$command));}elsif (-x ((
"\x2f\x75\x73\x72\x2f\x73\x62\x69\x6e\x2f".$command))){return ((
"\x2f\x75\x73\x72\x2f\x73\x62\x69\x6e\x2f".$command));}elsif (-x ((
"\x2f\x75\x73\x72\x2f\x6c\x6f\x63\x61\x6c\x2f\x62\x69\x6e\x2f".$command))){
return (("\x2f\x75\x73\x72\x2f\x6c\x6f\x63\x61\x6c\x2f\x62\x69\x6e\x2f".$command
));}elsif (-x (("\x2f\x75\x73\x72\x2f\x62\x69\x6e\x2f\x58\x31\x31\x2f".$command)
)){return (("\x2f\x75\x73\x72\x2f\x62\x69\x6e\x2f\x58\x31\x31\x2f".$command));}(my $path
=checkPathInPathVariable ($command));return ($path);}sub checkPathInPathVariable
{(my $command=shift (@_));(my $envPath=$ENV{"\x50\x41\x54\x48"});($envPath=~ s/^PATH=//gm )
;return ($pathNotFound);(my (@paths)=split ( /;/ ,$envPath,(0x0a6b+ 3263-0x172a)
));foreach my $path (@paths){(my $file=(($path.$GLOBAL::DIRECTORY_SLASH).
$command));if (-x ($file)){return ($file);}}return ($pathNotFound);}sub getPath{
(my $command=shift (@_));(my $ref_commandPath=getReferenceToSavedCommand (
$command));if ((not (defined ($$ref_commandPath)))){($$ref_commandPath=checkPath
 ($command));}(my $commandPath=$$ref_commandPath);return ($commandPath);}sub 
getCommand{(my (@args)=@_);(my $command=shift (@args));(my $ref_commandPath=
getReferenceToSavedCommand ($command));if ((not (defined ($$ref_commandPath)))){
($$ref_commandPath=checkPath ($command));}(my $commandPath=$$ref_commandPath);(my (
@reply)=());if (($commandPath ne $pathNotFound)){push (@reply,$commandPath,@args
);}else{push (@reply,$GLOBAL::CommandBash,"\x2d\x2d\x6c\x6f\x67\x69\x6e",
"\x2d\x63",main::shell_quote ($command,@args));}return (@reply);}sub 
getReferenceToSavedCommand{(my $command=shift (@_));(my $refCommand=((
"\x43\x6f\x6d\x6d\x6f\x6e\x3a\x3a\x4e\x58\x53\x68\x65\x6c\x6c\x43\x6f\x6d\x6d\x61\x6e\x64\x73\x3a\x3a"
.$command)."\x5f\x63\x6f\x6d\x6d\x61\x6e\x64"));return ($refCommand);}sub 
getReferenceToSavedCommandParameters{(my $command=shift (@_));(my $type=shift (
@_));(my $refOptions=((
"\x43\x6f\x6d\x6d\x6f\x6e\x3a\x3a\x4e\x58\x53\x68\x65\x6c\x6c\x43\x6f\x6d\x6d\x61\x6e\x64\x73\x3a\x3a"
.$command).("\x5f\x6f\x70\x74\x69\x6f\x6e\x73\x5f".$type)));return ($refOptions)
;}sub isApplicationInKnownPath{(my $command=shift (@_));(my $refCommand=
getReferenceToSavedCommand ($command));if ((not (defined ($$refCommand)))){(
$$refCommand=checkPath ($command));}(my $commandPath=$$refCommand);if ((
$commandPath ne $pathNotFound)){return ((0x0509+ 7449-0x2221));}return (
(0x109f+  51-0x10d2));}sub isPasswordRequestMessage{(my $message=shift (@_));if 
((((($message=~ /password for/ )or ($message=~ /Password/ ))or ($message=~ /'s password/ )
)or ($message=~ /assword:\ *$/ ))){return ((0x0600+ 8242-0x2631));}return (
(0x07f1+ 7614-0x25af));}sub isNotInSudoersMessage{(my $message=shift (@_));if ((
($message=~ /is not in the sudoers file/ )or ($message=~ /is not allowed to execute/ )
)){return ((0x0d96+ 4957-0x20f2));}return ((0x0823+ 1427-0x0db6));}sub 
isNotAdministrator{(my $message=shift (@_));if (($message=~ /Only a user with administrative privileges can use option/ )
){return ((0x0de1+ 1015-0x11d7));}return ((0x0f24+ 2231-0x17db));}sub 
getConnectionsForXserversCheck{(my $ref_cmd_out=shift (@_));(my $ref_exit_value=
shift (@_));(my (@command)=getNetStatisticsCommandForListeningUnix ());if ((
$command[(0x01ed+ 3058-0x0ddf)]eq $pathNotFound)){($$ref_exit_value=
(0x03bd+ 8726-0x25d2));return ((0x029f+ 9293-0x26ec));}my ($cmd_err);(($cmd_err,
$$ref_cmd_out,$$ref_exit_value)=main::run_command ((\@command),("")));if (
$$ref_exit_value){Logger::warning (((
"\x43\x6f\x6d\x6d\x61\x6e\x64\x20\x66\x6f\x72\x20\x6e\x65\x74\x20\x73\x74\x61\x74\x69\x73\x74\x69\x63\x73\x20\x72\x65\x74\x75\x72\x6e\x65\x64\x20\x27"
.$$ref_exit_value)."\x27\x2e"));Logger::warning (((
"\x43\x6f\x6d\x6d\x61\x6e\x64\x20\x66\x6f\x72\x20\x6e\x65\x74\x20\x73\x74\x61\x74\x69\x73\x74\x69\x63\x73\x20\x72\x65\x74\x75\x72\x6e\x65\x64\x20\x6f\x75\x74\x70\x75\x74\x20\x27"
.$$ref_cmd_out)."\x27\x2e"));Logger::warning (((
"\x43\x6f\x6d\x6d\x61\x6e\x64\x20\x66\x6f\x72\x20\x6e\x65\x74\x20\x73\x74\x61\x74\x69\x73\x74\x69\x63\x73\x20\x72\x65\x74\x75\x72\x6e\x65\x64\x20\x65\x72\x72\x6f\x72\x20\x27"
.$cmd_err)."\x27\x2e"));return ((0x0d98+ 6218-0x25e2));}return (
(0x01c9+ 8635-0x2383));}sub getListeningConnections{(my $ref_cmd_out=shift (@_))
;(my $ref_exit_value=shift (@_));(my (@command)=getNetStatisticsCommandForAllTcp
 ());if (($command[(0x1aa2+ 2739-0x2555)]eq $pathNotFound)){($$ref_exit_value=
(0x0187+ 2326-0x0a9c));return ((0x15e5+ 3024-0x21b5));}my ($cmd_err);(($cmd_err,
$$ref_cmd_out,$$ref_exit_value)=main::run_command ((\@command),("")));if (
$$ref_exit_value){return ((0x02b1+ 8133-0x2276));}return ((0x14a6+ 942-0x1853));
}sub getExtendedListeningConnectionsForFontServerChecking{(my $ref_cmd_out=shift
 (@_));(my $ref_exit_value=shift (@_));(my (@command)=
getNetStatisticsCommandForListeningTcpExtended ());if (($command[
(0x16ab+ 328-0x17f3)]eq $pathNotFound)){($$ref_exit_value=(0x0a0f+ 5678-0x203c))
;return ((0x008a+ 4104-0x1092));}my ($cmd_err);(($cmd_err,$$ref_cmd_out,
$$ref_exit_value)=main::run_command ((\@command),("")));if ($$ref_exit_value){
return ((0x0554+ 6197-0x1d89));}return ((0x0e7d+ 5101-0x2269));}sub 
getNetStatisticsComandWithPrioritySs{(my $commandPath=checkPath ("\x73\x73"));if
 (($commandPath eq $pathNotFound)){($commandPath=checkPath (
"\x6e\x65\x74\x73\x74\x61\x74"));if (($commandPath eq $pathNotFound)){
setNetStatisticsCommandIsNotFound ();}else{setNetStatisticsCommandIsNetstat ();}
}else{setNetStatisticsCommandIsSs ();}return ($commandPath);}sub 
getNetStatisticsComandWithPriorityNetstat{(my $commandPath=checkPath (
"\x6e\x65\x74\x73\x74\x61\x74"));if (($commandPath eq $pathNotFound)){(
$commandPath=checkPath ("\x73\x73"));if (($commandPath eq $pathNotFound)){
setNetStatisticsCommandIsNotFound ();}else{setNetStatisticsCommandIsSs ();}}else
{setNetStatisticsCommandIsNetstat ();}return ($commandPath);}sub 
setNetStatisticsCommand{(my $command=
"\x6e\x65\x74\x53\x74\x61\x74\x69\x73\x74\x69\x63\x73");if (
isNetStatisticsCommandSet ()){return;}(my $ref_commandPath=
getReferenceToSavedCommand ($command));if (
Common::NXInfo::doesOsPreferSsOverNetstat ()){($$ref_commandPath=
getNetStatisticsComandWithPrioritySs ());}else{($$ref_commandPath=
getNetStatisticsComandWithPriorityNetstat ());}}sub 
getNetStatisticsCommandForListeningUnix{setNetStatisticsCommand ();if (
isNetStatisticsCommandNetstat ()){return (getCommand (
"\x6e\x65\x74\x53\x74\x61\x74\x69\x73\x74\x69\x63\x73","\x2d\x6c\x6e",
"\x2d\x2d\x70\x72\x6f\x74\x6f\x63\x6f\x6c\x3d\x75\x6e\x69\x78"));}if (
isNetStatisticsCommandSs ()){return (getCommand (
"\x6e\x65\x74\x53\x74\x61\x74\x69\x73\x74\x69\x63\x73","\x2d\x6c\x6e\x78"));}
return ($pathNotFound);}sub getNetStatisticsCommandForAllTcp{
setNetStatisticsCommand ();return (getCommand (
"\x6e\x65\x74\x53\x74\x61\x74\x69\x73\x74\x69\x63\x73","\x2d\x61\x6e\x74"));}sub
 getNetStatisticsCommandForListeningTcpExtended{setNetStatisticsCommand ();if (
isNetStatisticsCommandNetstat ()){return (getCommand (
"\x6e\x65\x74\x53\x74\x61\x74\x69\x73\x74\x69\x63\x73","\x2d\x6e\x65\x74\x6c"));
}if (isNetStatisticsCommandSs ()){return (getCommand (
"\x6e\x65\x74\x53\x74\x61\x74\x69\x73\x74\x69\x63\x73","\x2d\x6e\x74\x6c"));}
return ($pathNotFound);}sub isNetStatisticsCommandSet{if (defined (
$netStatisticsCommand)){return ((0x15a3+ 2767-0x2071));}return (
(0x0327+ 7508-0x207b));}sub setNetStatisticsCommandIsNotFound{Logger::warning (
"\x43\x6f\x6d\x6d\x61\x6e\x64\x20\x66\x6f\x72\x20\x6e\x65\x74\x20\x73\x74\x61\x74\x69\x73\x74\x69\x63\x73\x20\x6e\x6f\x74\x20\x66\x6f\x75\x6e\x64\x2e"
);($netStatisticsCommand=$pathNotFound);}sub setNetStatisticsCommandIsSs{(
$netStatisticsCommand=$commandSs);}sub setNetStatisticsCommandIsNetstat{(
$netStatisticsCommand=$commandNetstat);}sub isNetStatisticsCommandNetstat{if ((
$netStatisticsCommand eq $commandNetstat)){return ((0x07dc+ 4283-0x1896));}
return ((0x1121+ 4735-0x23a0));}sub isNetStatisticsCommandSs{if ((
$netStatisticsCommand eq $commandSs)){return ((0x10c4+ 817-0x13f4));}return (
(0x1897+ 387-0x1a1a));}sub isNetStatisticsCommandAvailable{
setNetStatisticsCommand ();if (($netStatisticsCommand eq $pathNotFound)){return 
((0x01e7+ 4728-0x145f));}return ((0x04ac+ 8786-0x26fd));}sub 
isDbusDaemonCommandAvailable{(my $dbusDaemonPath=getPath (
"\x64\x62\x75\x73\x2d\x64\x61\x65\x6d\x6f\x6e"));if (($dbusDaemonPath eq 
$pathNotFound)){return ((0x1134+ 836-0x1478));}return ((0x037d+ 2322-0x0c8e));}
sub isDbusSendCommandAvailable{(my $dbusSendPath=getPath (
"\x64\x62\x75\x73\x2d\x73\x65\x6e\x64"));if (($dbusSendPath eq $pathNotFound)){
return ((0x11b6+ 2379-0x1b01));}return ((0x05f6+ 6346-0x1ebf));}sub 
isNotDbusSendCommandAvailable{return ((!isDbusSendCommandAvailable ()));}sub 
getDbusSendCommand{return (getPath ("\x64\x62\x75\x73\x2d\x73\x65\x6e\x64"));}
"\x3f\x3f\x3f";

==> nomachine-8.10.1-1-x86_64.pkg.tar.zst: NX/lib/perl/nxnode/Common/NXShellCommands.pm <==
############################################################################
#                                                                          #
#  Copyright (c) 2001, 2023 NoMachine, http://www.nomachine.com.           #
#                                                                          #
#  NXNODE, NX protocol compression and NX extensions to this software      #
#  are copyright of NoMachine. Redistribution and use of the present       #
#  software is allowed according to terms specified in the file LICENSE    #
#  which comes in the source distribution.                                 #
#                                                                          #
#  Check http://www.nomachine.com/licensing.html for applicability.        #
#                                                                          #
#  NX and NoMachine are trademarks of NoMachine S.a.r.l.                   #
#                                                                          #
#  All rights reserved.                                                    #
#                                                                          #
############################################################################
package Common::NXShellCommands;no warnings;($pathNotFound=
"\x5f\x5f\x4e\x4f\x4e\x45\x5f\x5f");($commandSs="\x5f\x5f\x53\x53\x5f\x5f");(
$commandNetstat="\x5f\x5f\x4e\x45\x54\x53\x54\x41\x54\x5f\x5f");sub checkPath{(my $command
=shift (@_));if (-x (("\x2f\x62\x69\x6e\x2f".$command))){return ((
"\x2f\x62\x69\x6e\x2f".$command));}elsif (-x (("\x2f\x73\x62\x69\x6e\x2f".
$command))){return (("\x2f\x73\x62\x69\x6e\x2f".$command));}elsif (-x ((
"\x2f\x75\x73\x72\x2f\x62\x69\x6e\x2f".$command))){return ((
"\x2f\x75\x73\x72\x2f\x62\x69\x6e\x2f".$command));}elsif (-x ((
"\x2f\x75\x73\x72\x2f\x73\x62\x69\x6e\x2f".$command))){return ((
"\x2f\x75\x73\x72\x2f\x73\x62\x69\x6e\x2f".$command));}elsif (-x ((
"\x2f\x75\x73\x72\x2f\x6c\x6f\x63\x61\x6c\x2f\x62\x69\x6e\x2f".$command))){
return (("\x2f\x75\x73\x72\x2f\x6c\x6f\x63\x61\x6c\x2f\x62\x69\x6e\x2f".$command
));}elsif (-x (("\x2f\x75\x73\x72\x2f\x62\x69\x6e\x2f\x58\x31\x31\x2f".$command)
)){return (("\x2f\x75\x73\x72\x2f\x62\x69\x6e\x2f\x58\x31\x31\x2f".$command));}(my $path
=checkPathInPathVariable ($command));return ($path);}sub checkPathInPathVariable
{(my $command=shift (@_));(my $envPath=$ENV{"\x50\x41\x54\x48"});($envPath=~ s/^PATH=//gm )
;return ($pathNotFound);(my (@paths)=split ( /;/ ,$envPath,(0x0104+ 8399-0x21d3)
));foreach my $path (@paths){(my $file=(($path.$GLOBAL::DIRECTORY_SLASH).
$command));if (-x ($file)){return ($file);}}return ($pathNotFound);}sub getPath{
(my $command=shift (@_));(my $ref_commandPath=getReferenceToSavedCommand (
$command));if ((not (defined ($$ref_commandPath)))){($$ref_commandPath=checkPath
 ($command));}(my $commandPath=$$ref_commandPath);return ($commandPath);}sub 
getCommand{(my (@args)=@_);(my $command=shift (@args));(my $ref_commandPath=
getReferenceToSavedCommand ($command));if ((not (defined ($$ref_commandPath)))){
($$ref_commandPath=checkPath ($command));}(my $commandPath=$$ref_commandPath);(my (
@reply)=());if (($commandPath ne $pathNotFound)){push (@reply,$commandPath,@args
);}else{push (@reply,$GLOBAL::CommandBash,"\x2d\x2d\x6c\x6f\x67\x69\x6e",
"\x2d\x63",main::shell_quote ($command,@args));}return (@reply);}sub 
getReferenceToSavedCommand{(my $command=shift (@_));(my $refCommand=((
"\x43\x6f\x6d\x6d\x6f\x6e\x3a\x3a\x4e\x58\x53\x68\x65\x6c\x6c\x43\x6f\x6d\x6d\x61\x6e\x64\x73\x3a\x3a"
.$command)."\x5f\x63\x6f\x6d\x6d\x61\x6e\x64"));return ($refCommand);}sub 
getReferenceToSavedCommandParameters{(my $command=shift (@_));(my $type=shift (
@_));(my $refOptions=((
"\x43\x6f\x6d\x6d\x6f\x6e\x3a\x3a\x4e\x58\x53\x68\x65\x6c\x6c\x43\x6f\x6d\x6d\x61\x6e\x64\x73\x3a\x3a"
.$command).("\x5f\x6f\x70\x74\x69\x6f\x6e\x73\x5f".$type)));return ($refOptions)
;}sub isApplicationInKnownPath{(my $command=shift (@_));(my $refCommand=
getReferenceToSavedCommand ($command));if ((not (defined ($$refCommand)))){(
$$refCommand=checkPath ($command));}(my $commandPath=$$refCommand);if ((
$commandPath ne $pathNotFound)){return ((0x02a0+ 591-0x04ee));}return (
(0x0597+ 7765-0x23ec));}sub isPasswordRequestMessage{(my $message=shift (@_));if
 ((((($message=~ /password for/ )or ($message=~ /Password/ ))or ($message=~ /'s password/ )
)or ($message=~ /assword:\ *$/ ))){return ((0x0953+ 6212-0x2196));}return (
(0x0700+ 6431-0x201f));}sub isNotInSudoersMessage{(my $message=shift (@_));if ((
($message=~ /is not in the sudoers file/ )or ($message=~ /is not allowed to execute/ )
)){return ((0x0299+ 9035-0x25e3));}return ((0x0716+ 1252-0x0bfa));}sub 
isNotAdministrator{(my $message=shift (@_));if (($message=~ /Only a user with administrative privileges can use option/ )
){return ((0x1fb8+ 1007-0x23a6));}return ((0x211b+ 1461-0x26d0));}sub 
getConnectionsForXserversCheck{(my $ref_cmd_out=shift (@_));(my $ref_exit_value=
shift (@_));(my (@command)=getNetStatisticsCommandForListeningUnix ());if ((
$command[(0x2054+ 269-0x2161)]eq $pathNotFound)){($$ref_exit_value=
(0x00a2+ 9607-0x2628));return ((0x0b5d+ 6874-0x2637));}my ($cmd_err);(($cmd_err,
$$ref_cmd_out,$$ref_exit_value)=main::run_command ((\@command),("")));if (
$$ref_exit_value){Logger::warning (((
"\x43\x6f\x6d\x6d\x61\x6e\x64\x20\x66\x6f\x72\x20\x6e\x65\x74\x20\x73\x74\x61\x74\x69\x73\x74\x69\x63\x73\x20\x72\x65\x74\x75\x72\x6e\x65\x64\x20\x27"
.$$ref_exit_value)."\x27\x2e"));Logger::warning (((
"\x43\x6f\x6d\x6d\x61\x6e\x64\x20\x66\x6f\x72\x20\x6e\x65\x74\x20\x73\x74\x61\x74\x69\x73\x74\x69\x63\x73\x20\x72\x65\x74\x75\x72\x6e\x65\x64\x20\x6f\x75\x74\x70\x75\x74\x20\x27"
.$$ref_cmd_out)."\x27\x2e"));Logger::warning (((
"\x43\x6f\x6d\x6d\x61\x6e\x64\x20\x66\x6f\x72\x20\x6e\x65\x74\x20\x73\x74\x61\x74\x69\x73\x74\x69\x63\x73\x20\x72\x65\x74\x75\x72\x6e\x65\x64\x20\x65\x72\x72\x6f\x72\x20\x27"
.$cmd_err)."\x27\x2e"));return ((0x1090+ 3686-0x1ef6));}return (
(0x0107+ 4495-0x1295));}sub getListeningConnections{(my $ref_cmd_out=shift (@_))
;(my $ref_exit_value=shift (@_));(my (@command)=getNetStatisticsCommandForAllTcp
 ());if (($command[(0x08af+ 5943-0x1fe6)]eq $pathNotFound)){($$ref_exit_value=
(0x168a+ 3394-0x23cb));return ((0x1a56+ 965-0x1e1b));}my ($cmd_err);(($cmd_err,
$$ref_cmd_out,$$ref_exit_value)=main::run_command ((\@command),("")));if (
$$ref_exit_value){return ((0x0061+ 9237-0x2476));}return ((0x0668+ 7850-0x2511))
;}sub getExtendedListeningConnectionsForFontServerChecking{(my $ref_cmd_out=
shift (@_));(my $ref_exit_value=shift (@_));(my (@command)=
getNetStatisticsCommandForListeningTcpExtended ());if (($command[
(0x1d56+ 949-0x210b)]eq $pathNotFound)){($$ref_exit_value=(0x1d59+ 493-0x1f45));
return ((0x0c59+ 1867-0x13a4));}my ($cmd_err);(($cmd_err,$$ref_cmd_out,
$$ref_exit_value)=main::run_command ((\@command),("")));if ($$ref_exit_value){
return ((0x0568+ 7506-0x22ba));}return ((0x0cc3+ 417-0x0e63));}sub 
getNetStatisticsComandWithPrioritySs{(my $commandPath=checkPath ("\x73\x73"));if
 (($commandPath eq $pathNotFound)){($commandPath=checkPath (
"\x6e\x65\x74\x73\x74\x61\x74"));if (($commandPath eq $pathNotFound)){
setNetStatisticsCommandIsNotFound ();}else{setNetStatisticsCommandIsNetstat ();}
}else{setNetStatisticsCommandIsSs ();}return ($commandPath);}sub 
getNetStatisticsComandWithPriorityNetstat{(my $commandPath=checkPath (
"\x6e\x65\x74\x73\x74\x61\x74"));if (($commandPath eq $pathNotFound)){(
$commandPath=checkPath ("\x73\x73"));if (($commandPath eq $pathNotFound)){
setNetStatisticsCommandIsNotFound ();}else{setNetStatisticsCommandIsSs ();}}else
{setNetStatisticsCommandIsNetstat ();}return ($commandPath);}sub 
setNetStatisticsCommand{(my $command=
"\x6e\x65\x74\x53\x74\x61\x74\x69\x73\x74\x69\x63\x73");if (
isNetStatisticsCommandSet ()){return;}(my $ref_commandPath=
getReferenceToSavedCommand ($command));if (
Common::NXInfo::doesOsPreferSsOverNetstat ()){($$ref_commandPath=
getNetStatisticsComandWithPrioritySs ());}else{($$ref_commandPath=
getNetStatisticsComandWithPriorityNetstat ());}}sub 
getNetStatisticsCommandForListeningUnix{setNetStatisticsCommand ();if (
isNetStatisticsCommandNetstat ()){return (getCommand (
"\x6e\x65\x74\x53\x74\x61\x74\x69\x73\x74\x69\x63\x73","\x2d\x6c\x6e",
"\x2d\x2d\x70\x72\x6f\x74\x6f\x63\x6f\x6c\x3d\x75\x6e\x69\x78"));}if (
isNetStatisticsCommandSs ()){return (getCommand (
"\x6e\x65\x74\x53\x74\x61\x74\x69\x73\x74\x69\x63\x73","\x2d\x6c\x6e\x78"));}
return ($pathNotFound);}sub getNetStatisticsCommandForAllTcp{
setNetStatisticsCommand ();return (getCommand (
"\x6e\x65\x74\x53\x74\x61\x74\x69\x73\x74\x69\x63\x73","\x2d\x61\x6e\x74"));}sub
 getNetStatisticsCommandForListeningTcpExtended{setNetStatisticsCommand ();if (
isNetStatisticsCommandNetstat ()){return (getCommand (
"\x6e\x65\x74\x53\x74\x61\x74\x69\x73\x74\x69\x63\x73","\x2d\x6e\x65\x74\x6c"));
}if (isNetStatisticsCommandSs ()){return (getCommand (
"\x6e\x65\x74\x53\x74\x61\x74\x69\x73\x74\x69\x63\x73","\x2d\x6e\x74\x6c"));}
return ($pathNotFound);}sub isNetStatisticsCommandSet{if (defined (
$netStatisticsCommand)){return ((0x010b+ 4460-0x1276));}return (
(0x1a74+ 2892-0x25c0));}sub setNetStatisticsCommandIsNotFound{Logger::warning (
"\x43\x6f\x6d\x6d\x61\x6e\x64\x20\x66\x6f\x72\x20\x6e\x65\x74\x20\x73\x74\x61\x74\x69\x73\x74\x69\x63\x73\x20\x6e\x6f\x74\x20\x66\x6f\x75\x6e\x64\x2e"
);($netStatisticsCommand=$pathNotFound);}sub setNetStatisticsCommandIsSs{(
$netStatisticsCommand=$commandSs);}sub setNetStatisticsCommandIsNetstat{(
$netStatisticsCommand=$commandNetstat);}sub isNetStatisticsCommandNetstat{if ((
$netStatisticsCommand eq $commandNetstat)){return ((0x1747+ 1123-0x1ba9));}
return ((0x1726+ 2018-0x1f08));}sub isNetStatisticsCommandSs{if ((
$netStatisticsCommand eq $commandSs)){return ((0x1d16+ 2511-0x26e4));}return (
(0x177a+ 2620-0x21b6));}sub isNetStatisticsCommandAvailable{
setNetStatisticsCommand ();if (($netStatisticsCommand eq $pathNotFound)){return 
((0x0660+ 2439-0x0fe7));}return ((0x1377+ 2156-0x1be2));}sub 
isDbusDaemonCommandAvailable{(my $dbusDaemonPath=getPath (
"\x64\x62\x75\x73\x2d\x64\x61\x65\x6d\x6f\x6e"));if (($dbusDaemonPath eq 
$pathNotFound)){return ((0x0602+ 5715-0x1c55));}return ((0x1321+ 4008-0x22c8));}
sub isDbusSendCommandAvailable{(my $dbusSendPath=getPath (
"\x64\x62\x75\x73\x2d\x73\x65\x6e\x64"));if (($dbusSendPath eq $pathNotFound)){
return ((0x0221+ 4524-0x13cd));}return ((0x0ecc+ 6162-0x26dd));}sub 
isNotDbusSendCommandAvailable{return ((!isDbusSendCommandAvailable ()));}sub 
getDbusSendCommand{return (getPath ("\x64\x62\x75\x73\x2d\x73\x65\x6e\x64"));}
"\x3f\x3f\x3f";
